from collections import Counter
data = [1,1,3,2,3,5]
x = Counter(data)
y = '12334123'
z = '324'
print(z in y)